@@ -14,33 +14,19 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from flask_appbuilder import ModelRestApi
 from flask_appbuilder.models.sqla.interface import SQLAInterface
 
-from superset import app, appbuilder
 import superset.models.core as models
+from superset.views.base_api import BaseSupersetModelRestApi
+
 from . import LogMixin
 
 
-class LogRestApi(LogMixin, ModelRestApi):
+class LogRestApi(LogMixin, BaseSupersetModelRestApi):
     datamodel = SQLAInterface(models.Log)
-
+    include_route_methods = {"get_list", "get", "post"}
     class_permission_name = "LogModelView"
-    method_permission_name = {
-        "get_list": "list",
-        "get": "show",
-        "post": "add",
-        "put": "edit",
-        "delete": "delete",
-        "info": "list",
-    }
     resource_name = "log"
     allow_browser_login = True
-    list_columns = ("user.username", "action", "dttm")
-
-
-if (
-    not app.config.get("FAB_ADD_SECURITY_VIEWS") is False
-    or app.config.get("SUPERSET_LOG_VIEW") is False
-):
-    appbuilder.add_api(LogRestApi)
+    list_columns = ["user.username", "action", "dttm"]
+    show_columns = list_columns
